pub unsafe extern "C" fn tsk_site_table_equals(
self_: *const tsk_site_table_t,
other: *const tsk_site_table_t,
options: tsk_flags_t,
) -> boolAvailable on crate feature
bindings only.Expand description
@brief Returns true if the data in the specified table is identical to the data in this table.
@rst
Options**
Options to control the comparison can be specified by providing one or more of the following bitwise flags. By default (options=0) tables are considered equal if they are byte-wise identical in all columns, and their metadata schemas are byte-wise identical.
- :c:macro:
TSK_CMP_IGNORE_METADATA@endrst
@param self A pointer to a tsk_site_table_t object. @param other A pointer to a tsk_site_table_t object. @param options Bitwise comparison options. @return Return true if the specified table is equal to this table.