tsk_tree_last

Function tsk_tree_last 

pub unsafe extern "C" fn tsk_tree_last(
    self_: *mut tsk_tree_t,
) -> c_int
Available on crate feature bindings only.
@brief Seek to the last tree in the sequence.

@rst Set the state of this tree to reflect the last tree in parent tree sequence. @endrst

@param self A pointer to an initialised tsk_tree_t object. @return Return TSK_TREE_OK on success; or a negative value if an error occurs.