tsk_tree_print_state

Function tsk_tree_print_state 

pub unsafe extern "C" fn tsk_tree_print_state(
    self_: *const tsk_tree_t,
    out: *mut FILE,
)
Available on crate feature bindings only.
@brief Print out the state of this tree to the specified stream.

This method is intended for debugging purposes and should not be used in production code. The format of the output should not be depended on and may change arbitrarily between versions.

@param self A pointer to a tsk_tree_t object. @param out The stream to write the summary to.