pub unsafe extern "C" fn tsk_variant_restricted_copy(
self_: *const tsk_variant_t,
other: *mut tsk_variant_t,
) -> c_intAvailable on crate feature
bindings only.Expand description
@brief Copies the state of this variant to another variant
@rst
Copies the site, genotypes and alleles from this variant to another. Note that
the other variant should be uninitialised as this method does not free any
memory that the other variant owns. After copying other is frozen and
this restricts it from being further decoded at any site. self remains unchanged.
@endrst
@param self A pointer to an initialised and decoded tsk_variant_t object. @param other A pointer to an uninitialised tsk_variant_t object. @return Return 0 on success or a negative value on failure.