tsk_flags_t

Type Alias tsk_flags_t 

pub type tsk_flags_t = u32;
Available on crate feature bindings only.
@brief Container for bitwise flags.

@rst Bitwise flags are used in tskit as a column type and also as a way to specify options to API functions. @endrst